@@ -21,7 +21,7 @@ module Mocha
 
   class Name
     def initialize(name)
-      @name = name
+      @name = name.to_s
     end
 
     def mocha_inspect
@@ -37,7 +37,7 @@ module Mocha
     def mocha_inspect
       address = @mock.__id__ * 2
       address += 0x100000000 if address < 0
-      "#<Mock:0x#{format('%x', address)}>"
+      "#<Mock:0x#{format('%<address>x', address: address)}>"
     end
   end
 end
