@@ -3,8 +3,9 @@ require 'mocha/parameter_matchers'
 
 module Mocha
   class ParametersMatcher
-    def initialize(expected_parameters = [ParameterMatchers::AnyParameters.new], &matching_block)
+    def initialize(expected_parameters = [ParameterMatchers::AnyParameters.new], expectation = nil, &matching_block)
       @expected_parameters = expected_parameters
+      @expectation = expectation
       @matching_block = matching_block
     end
 
@@ -23,12 +24,11 @@ module Mocha
     def mocha_inspect
       signature = matchers.mocha_inspect
       signature = signature.gsub(/^\[|\]$/, '')
-      signature = signature.gsub(/^\{|\}$/, '') if matchers.length == 1
       "(#{signature})"
     end
 
     def matchers
-      @expected_parameters.map(&:to_matcher)
+      @expected_parameters.map { |p| p.to_matcher(expectation: @expectation, top_level: true) }
     end
   end
 end
