@@ -22,7 +22,7 @@ class ReturnValueTest < Mocha::TestCase
 
   def test_should_build_mock_incorporating_two_expectations_with_return_values
     test_result = run_as_test do
-      foo = mock('foo', :bar => 'bar', :baz => 'baz')
+      foo = mock('foo', bar: 'bar', baz: 'baz')
       assert_equal 'bar', foo.bar
       assert_equal 'baz', foo.baz
     end
@@ -40,7 +40,7 @@ class ReturnValueTest < Mocha::TestCase
 
   def test_should_build_stub_incorporating_two_expectations_with_return_values
     test_result = run_as_test do
-      foo = stub('foo', :bar => 'bar', :baz => 'baz')
+      foo = stub('foo', bar: 'bar', baz: 'baz')
       assert_equal 'bar', foo.bar
       assert_equal 'baz', foo.baz
     end
