@@ -1,5 +1,4 @@
 require File.expand_path('../acceptance_test_helper', __FILE__)
-require 'mocha/setup'
 
 class SequenceTest < Mocha::TestCase
   include AcceptanceTest
@@ -24,6 +23,7 @@ class SequenceTest < Mocha::TestCase
       mock.first
     end
     assert_failed(test_result)
+    assert_match 'second() invoked out of order', test_result.failures.first.message
   end
 
   def test_should_allow_invocations_in_sequence
@@ -83,6 +83,7 @@ class SequenceTest < Mocha::TestCase
       partial_mock_one.first
     end
     assert_failed(test_result)
+    assert_match 'second() invoked out of order', test_result.failures.first.message
   end
 
   def test_should_allow_invocations_in_sequence_even_if_expected_on_partial_mocks
