@@ -107,21 +107,6 @@ class StubModuleMethodTest < Mocha::TestCase
     assert_equal :original_return_value, supermod.my_superclass_method
   end
 
-  def test_should_be_able_to_stub_method_if_ruby18_public_methods_include_method_but_method_does_not_actually_exist_like_active_record_association_proxy
-    ruby18_mod = Module.new do
-      class << self
-        def public_methods(_include_superclass = true)
-          ['my_module_method']
-        end
-      end
-    end
-    test_result = run_as_test do
-      ruby18_mod.stubs(:my_module_method).returns(:new_return_value)
-      assert_equal :new_return_value, ruby18_mod.my_module_method
-    end
-    assert_passed(test_result)
-  end
-
   def test_should_be_able_to_stub_method_if_ruby19_public_methods_include_method_but_method_does_not_actually_exist_like_active_record_association_proxy
     ruby19_mod = Module.new do
       class << self
@@ -137,21 +122,6 @@ class StubModuleMethodTest < Mocha::TestCase
     assert_passed(test_result)
   end
 
-  def test_should_be_able_to_stub_method_if_ruby_18_protected_methods_include_method_but_method_does_not_actually_exist_like_active_record_association_proxy
-    ruby18_mod = Module.new do
-      class << self
-        def protected_methods(_include_superclass = true)
-          ['my_module_method']
-        end
-      end
-    end
-    test_result = run_as_test do
-      ruby18_mod.stubs(:my_module_method).returns(:new_return_value)
-      assert_equal :new_return_value, ruby18_mod.my_module_method
-    end
-    assert_passed(test_result)
-  end
-
   def test_should_be_able_to_stub_method_if_ruby19_protected_methods_include_method_but_method_does_not_actually_exist_like_active_record_association_proxy
     ruby19_mod = Module.new do
       class << self
@@ -167,21 +137,6 @@ class StubModuleMethodTest < Mocha::TestCase
     assert_passed(test_result)
   end
 
-  def test_should_be_able_to_stub_method_if_ruby18_private_methods_include_method_but_method_does_not_actually_exist_like_active_record_association_proxy
-    ruby18_mod = Module.new do
-      class << self
-        def private_methods(_include_superclass = true)
-          ['my_module_method']
-        end
-      end
-    end
-    test_result = run_as_test do
-      ruby18_mod.stubs(:my_module_method).returns(:new_return_value)
-      assert_equal :new_return_value, ruby18_mod.my_module_method
-    end
-    assert_passed(test_result)
-  end
-
   def test_should_be_able_to_stub_method_if_ruby19_private_methods_include_method_but_method_does_not_actually_exist_like_active_record_association_proxy
     ruby19_mod = Module.new do
       class << self
