@@ -1,5 +1,4 @@
 require File.expand_path('../acceptance_test_helper', __FILE__)
-require 'mocha/setup'
 require 'execution_point'
 
 class StubbingFrozenObjectTest < Mocha::TestCase
@@ -13,7 +12,6 @@ class StubbingFrozenObjectTest < Mocha::TestCase
     teardown_acceptance_test
   end
 
-  # rubocop:disable Style/Semicolon
   def test_should_fail_fast_if_attempting_to_stub_method_on_frozen_object
     object = Object.new
     object.freeze
@@ -21,8 +19,7 @@ class StubbingFrozenObjectTest < Mocha::TestCase
     test_result = run_as_test do
       execution_point = ExecutionPoint.current; object.stubs(:stubbed_method)
     end
-    assert_failed(test_result)
-    assert_equal 1, test_result.error_count
+    assert_errored(test_result)
     assert_equal execution_point, ExecutionPoint.new(test_result.errors[0].exception.backtrace)
   end
 
@@ -33,8 +30,7 @@ class StubbingFrozenObjectTest < Mocha::TestCase
     test_result = run_as_test do
       execution_point = ExecutionPoint.current; object.expects(:stubbed_method)
     end
-    assert_failed(test_result)
-    assert_equal 1, test_result.error_count
+    assert_errored(test_result)
     assert_equal execution_point, ExecutionPoint.new(test_result.errors[0].exception.backtrace)
   end
 
@@ -45,8 +41,7 @@ class StubbingFrozenObjectTest < Mocha::TestCase
     test_result = run_as_test do
       execution_point = ExecutionPoint.current; klass.stubs(:stubbed_method)
     end
-    assert_failed(test_result)
-    assert_equal 1, test_result.error_count
+    assert_errored(test_result)
     assert_equal execution_point, ExecutionPoint.new(test_result.errors[0].exception.backtrace)
   end
 
@@ -57,8 +52,7 @@ class StubbingFrozenObjectTest < Mocha::TestCase
     test_result = run_as_test do
       execution_point = ExecutionPoint.current; klass.expects(:stubbed_method)
     end
-    assert_failed(test_result)
-    assert_equal 1, test_result.error_count
+    assert_errored(test_result)
     assert_equal execution_point, ExecutionPoint.new(test_result.errors[0].exception.backtrace)
   end
 
@@ -69,8 +63,7 @@ class StubbingFrozenObjectTest < Mocha::TestCase
     test_result = run_as_test do
       execution_point = ExecutionPoint.current; klass.any_instance.stubs(:stubbed_method)
     end
-    assert_failed(test_result)
-    assert_equal 1, test_result.error_count
+    assert_errored(test_result)
     assert_equal execution_point, ExecutionPoint.new(test_result.errors[0].exception.backtrace)
   end
 
@@ -81,9 +74,7 @@ class StubbingFrozenObjectTest < Mocha::TestCase
     test_result = run_as_test do
       execution_point = ExecutionPoint.current; klass.any_instance.expects(:stubbed_method)
     end
-    assert_failed(test_result)
-    assert_equal 1, test_result.error_count
+    assert_errored(test_result)
     assert_equal execution_point, ExecutionPoint.new(test_result.errors[0].exception.backtrace)
   end
-  # rubocop:enable Style/Semicolon
 end
