@@ -2,13 +2,9 @@ require File.expand_path('../../test_helper', __FILE__)
 require 'mocha/expectation'
 require 'mocha/invocation'
 require 'mocha/sequence'
-require 'mocha/configuration'
-require 'mocha/deprecation'
 require 'execution_point'
 require 'simple_counter'
-require 'deprecation_disabler'
 
-# rubocop:disable  Metrics/ClassLength
 class ExpectationTest < Mocha::TestCase
   include Mocha
 
@@ -97,12 +93,10 @@ class ExpectationTest < Mocha::TestCase
     assert_equal backtrace, Expectation.new(nil, :expected_method, backtrace).backtrace
   end
 
-  # rubocop:disable Style/Semicolon
   def test_should_default_backtrace_to_caller
     execution_point = ExecutionPoint.current; expectation = Expectation.new(nil, :expected_method)
     assert_equal execution_point, ExecutionPoint.new(expectation.backtrace)
   end
-  # rubocop:enable Style/Semicolon
 
   def test_should_not_yield
     yielded = false
@@ -116,32 +110,12 @@ class ExpectationTest < Mocha::TestCase
     assert_equal [], yielded_parameters
   end
 
-  def test_yield_should_fail_when_the_caller_does_not_provide_a_block_and_behaviour_from_v1_9_not_retained
+  def test_yields_should_raise_local_jump_error_when_the_caller_does_not_provide_a_block
     assert_raises(LocalJumpError) { invoke(new_expectation.yields(:foo)) }
   end
 
-  def test_yields_should_display_warning_when_caller_does_not_provide_block
-    Mocha::Configuration.override(:reinstate_undocumented_behaviour_from_v1_9 => true) do
-      DeprecationDisabler.disable_deprecations do
-        invoke(new_expectation.yields(:foo, 1, [2, 3]))
-      end
-    end
-    assert message = Deprecation.messages.last
-    assert message.include?('Stubbed method was instructed to yield (:foo, 1, [2, 3])')
-    assert message.include?('but no block was given by invocation: :irrelevant.expected_method()')
-    assert message.include?('This will raise a LocalJumpError in the future.')
-  end
-
-  def test_multiple_yields_should_display_warning_when_caller_does_not_provide_block
-    Mocha::Configuration.override(:reinstate_undocumented_behaviour_from_v1_9 => true) do
-      DeprecationDisabler.disable_deprecations do
-        invoke(new_expectation.multiple_yields(:foo, 1, [2, 3]))
-      end
-    end
-    assert message = Deprecation.messages.last
-    assert message.include?('Stubbed method was instructed to yield (2, 3)')
-    assert message.include?('but no block was given by invocation: :irrelevant.expected_method()')
-    assert message.include?('This will raise a LocalJumpError in the future.')
+  def test_multiple_yields_should_raise_local_jump_error_when_caller_does_not_provide_block
+    assert_raises(LocalJumpError) { invoke(new_expectation.multiple_yields(:foo, 1, [2, 3])) }
   end
 
   def test_should_yield_with_specified_parameters
@@ -336,12 +310,10 @@ class ExpectationTest < Mocha::TestCase
     assert_equal 0, assertion_counter.count
   end
 
-  # rubocop:disable Style/Semicolon
   def test_should_store_backtrace_from_point_where_expectation_was_created
     execution_point = ExecutionPoint.current; expectation = Expectation.new(nil, :expected_method)
     assert_equal execution_point, ExecutionPoint.new(expectation.backtrace)
   end
-  # rubocop:enable Style/Semicolon
 
   class FakeMock
     def initialize(name)
@@ -357,7 +329,7 @@ class ExpectationTest < Mocha::TestCase
     mock = FakeMock.new('mock')
     sequence_one = Sequence.new('one')
     sequence_two = Sequence.new('two')
-    expectation = Expectation.new(mock, :expected_method).with(1, 2, { 'a' => true }, { :b => false }, [1, 2, 3]).in_sequence(sequence_one, sequence_two)
+    expectation = Expectation.new(mock, :expected_method).with(1, 2, { 'a' => true }, { b: false }, [1, 2, 3]).in_sequence(sequence_one, sequence_two)
     assert !expectation.verified?
     assert_match %{mock.expected_method(1, 2, {"a" => true}, {:b => false}, [1, 2, 3]); in sequence "one"; in sequence "two"}, expectation.mocha_inspect
   end
@@ -503,4 +475,3 @@ class ExpectationTest < Mocha::TestCase
     assert expectation.inspect.include?(expectation.mocha_inspect)
   end
 end
-# rubocop:enable  Metrics/ClassLength
