@@ -2,6 +2,7 @@ require File.expand_path('../../test_helper', __FILE__)
 require 'mocha/ruby_version'
 require 'method_definer'
 require 'mocha/class_methods'
+require 'mocha/mockery'
 require 'mocha/mock'
 
 require 'mocha/instance_method'
@@ -238,6 +239,6 @@ class InstanceMethodTest < Mocha::TestCase
   private
 
   def build_mock
-    Mock.new(nil)
+    Mock.new(Mockery.new)
   end
 end
