@@ -66,12 +66,12 @@ class IncludesTest < Mocha::TestCase
 
   def test_should_match_object_including_value_which_matches_nested_matcher
     matcher = includes(has_key(:key))
-    assert matcher.matches?([[:non_matching_element, { :key => 'value' }]])
+    assert matcher.matches?([[:non_matching_element, { key: 'value' }]])
   end
 
   def test_should_not_match_object_which_doesnt_include_value_that_matches_nested_matcher
     matcher = includes(has_key(:key))
-    assert !matcher.matches?([[:non_matching_element, { :other_key => 'other-value' }]])
+    assert !matcher.matches?([[:non_matching_element, { other_key: 'other-value' }]])
   end
 
   def test_should_match_string_argument_containing_substring
@@ -86,12 +86,12 @@ class IncludesTest < Mocha::TestCase
 
   def test_should_match_hash_argument_containing_given_key
     matcher = includes(:key)
-    assert matcher.matches?([{ :thing => 1, :key => 2 }])
+    assert matcher.matches?([{ thing: 1, key: 2 }])
   end
 
   def test_should_not_match_hash_argument_missing_given_key
     matcher = includes(:key)
-    assert !matcher.matches?([{ :thing => 1, :other => :key }])
+    assert !matcher.matches?([{ thing: 1, other: :key }])
   end
 
   def test_should_match_hash_when_nested_matcher_matches_key
