@@ -38,8 +38,8 @@ class YieldParametersTest < Mocha::TestCase
 
   def test_should_return_multiple_yield_parameter_group_when_arguments_are_not_arrays
     yield_parameters = YieldParameters.new
-    yield_parameters.add(1, { :b => 2 }, 3)
-    assert_next_invocation_yields(yield_parameters, [[1], [{ :b => 2 }], [3]])
+    yield_parameters.add(1, { b: 2 }, 3)
+    assert_next_invocation_yields(yield_parameters, [[1], [{ b: 2 }], [3]])
   end
 
   def test_should_keep_returning_multiple_yield_parameter_group
